@@ -1,9 +1,11 @@
-dl_trips_data_oslo <- function(year, month) {
+dl_trips_data_oslo <- function(year, month, filetype = "CSV") {
+
+  filetype <- tolower(filetype)
 
   if (year >= 2019) {
 
     base_url <- "http://data.urbansharing.com/oslobysykkel.no/trips/v1"
-    dl_url <- glue::glue("{base_url}/{year}/{sprintf('%0.2d', month)}.csv")
+    dl_url <- glue::glue("{base_url}/{year}/{sprintf('%0.2d', month)}.{filetype}")
 
     if (httr::http_error(dl_url)) {
 
@@ -11,12 +13,13 @@ dl_trips_data_oslo <- function(year, month) {
 
     }
 
-    download.file(url = dl_url)
+    output_file <- glue::glue("trips_oslo_{year}_{sprintf('%0.2d', month)}.{filetype}")
+    download.file(url = dl_url, destfile = output_file)
 
   } else if (year < 2019) {
 
     base_url <- "https://data-legacy.urbansharing.com/oslobysykkel.no"
-    dl_url <- glue::glue("{base_url}/{year}/{sprintf('%0.2d', month)}.csv.zip")
+    dl_url <- glue::glue("{base_url}/{year}/{sprintf('%0.2d', month)}.{filetype}.zip")
 
     if (httr::http_error(dl_url)) {
 
